pub struct LayoutOptions {
pub direction: LayoutDirection,
pub node_gap: f64,
pub rank_gap: f64,
pub update_handle_sides: bool,
}Expand description
Options for compute_layout.
Fields
direction: LayoutDirectionnode_gap: f64Gap between adjacent nodes within a rank, in flow units.
rank_gap: f64Gap between ranks, in flow units.
update_handle_sides: boolWhen applied through the flow, also point node handles along the layout direction (e.g. left/right for horizontal layouts).
Implementations
Sourceimpl LayoutOptions
impl LayoutOptions